﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Windows;
using System.Threading;
using System.Windows.Data;


namespace Microsoft.Forums.ForumsClient.Views
{
    /// <summary>
    ///  Formatter class to convert a string to visibility representing empty or non empty
    /// </summary>
    [ValueConversion(typeof(string),typeof(Visibility))]
    public class IsStringEmptyToVisibilityConverter : IValueConverter
    {
        /// <summary>
        /// Convert Implementation.
        /// </summary>
        /// <param name="value">String to be checked for emptiness</param>
        /// <param name="targetType">The type of the binding target property</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>True if not empty</returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            string stringToCheck = value as string;

            if (stringToCheck == null || String.IsNullOrEmpty(stringToCheck))
            {
                return Visibility.Hidden;
            }
            else
            {
                return Visibility.Visible; ;
            }
        }


        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <param name="value">The value that is produced by the binding target.</param>
        /// <param name="targetType">The type to convert to.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotSupportedException("ConvertBack is not supported for FormatToString");
        }

    }
}