﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Data;
using Microsoft.Forums.OfflineStore;

namespace Microsoft.Forums.ForumsClient.Views
{
    /// <summary>
    ///  Class to convert a boolean property to System.Windows.Visibility with
    ///  True -> Hidden
    ///  False -> Visible
    /// </summary>
    public class NegatedBooleanToVisibleConverter : IValueConverter
    {
        /// <summary>
        /// If the value is true then the return Hidden
        /// </summary>
        /// <param name="value">boolean rvalue</param>
        /// <param name="targetType">Should be System.Windows.Visibility</param>
        /// <param name="parameter">not used</param>
        /// <param name="culture">not used</param>
        /// <returns>System.Windows.Visibility.Hidden if value is true. Otherwise, System.Windows.Visibility.Visible or </returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value == null)
                throw new ArgumentNullException("value");
            if (targetType != typeof(System.Windows.Visibility))
                throw new InvalidCastException("Unexpected type of " + targetType.ToString());
            return ((bool)value ? System.Windows.Visibility.Hidden : System.Windows.Visibility.Visible);
        }

        /// <summary>
        /// Method Not Implemented. Throws NotSupportedException
        /// </summary>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotSupportedException("ConvertBack is not supported.");
        }
    }
}
