﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Microsoft.Forums.SyncService
{
    /// <summary>
    /// Contains the results of a Post Synchronization
    /// </summary>
    public class SynchronizePostSummary : ISynchronizeSummary
    {
        /// <summary>
        /// Id of the thread which was synchronized
        /// </summary>
        public Guid ThreadId
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the forum id.
        /// </summary>
        /// <value>The forum id.</value>
        public Guid ForumId
        {
            get;
            private set;
        }

        /// <summary>
        /// Id of post
        /// </summary>
        public Guid PostId
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets or sets the type of the synchronize.
        /// </summary>
        /// <value>The type of the synchronize.</value>
        public SynchronizeType SynchronizeType
        {
            get;
            private set;
        }

        /// <summary>
        /// Creates a summary object for the synchronization of a post
        /// </summary>
        /// <param name="threadId">Id of Thread which was synchronized</param>
        /// <param name="postIds">Id of the post which were updated or added</param>
        public SynchronizePostSummary(Guid forumId, Guid threadId, Guid postId, SynchronizeType syncType)
        {
            ForumId = forumId;
            PostId = postId;
            ThreadId = threadId;
            SynchronizeType = syncType;
        }

    }
}
